checkRequire("Lua_ShopBasePanel");
checkRequire("Lua_ShopSecondItem");
Lua_ShopPanel = class("Lua_ShopPanel", Lua_ShopBasePanel);
function Lua_ShopPanel:ctor(p)
	self:superCall("ctor", p, "ShopPanel_skin");
end

function Lua_ShopPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 633, 600 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_ShopSecondItem, 633, 260, 1);
	self.itemList:setRectPivot(1);
	self.itemList:setRectAnchor(1);
	self.itemList:setCellSpacing(-75, 19);
	self.itemList:setLocation(-1, -600, 0);
	self.itemList.tweenId = 2013;

	self.refreshBtn:setEnable(false);

	self:addLuaEvent("UPDATE_SHOP_INFO", self, self.updateShowInfo);
end

function Lua_ShopPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:removeTimer(self, self.updateTimer);

	self:superCall("dispose");
end

function Lua_ShopPanel:onScreenResize(adaptHeight)
	if self.adaptHeight ~= adaptHeight then
		self:superCall("onScreenResize", adaptHeight);
		self.itemList:setContentRect(633, 623 + adaptHeight);
	end
end

function Lua_ShopPanel:setData(data)
	self:superCall("setData", data);

	self.isShowRefreshBtn = data.refresh;
	self.shopType = data.shopType;
end

function Lua_ShopPanel:updateShowInfo()
	if self.data == nil then
		return;
	end

	self.refreshBtn:setEnable(self.isShowRefreshBtn ~= nil);
	local list = DataCenter.shopData:getCurShopItemList(self.shopType);

	local index = 1;
	local num = 0;
	local showList = {};
	for i = 1, #list do
		if showList[index] == nil then
			showList[index] = Array();
		end
		showList[index]:add(list[i]);

		num = num + 1;
		if num >= 3 then
			index = index + 1;
			num = 0;
		end
	end
	self.itemList:setArrayData(showList, nil);
	
	--显示刷新处理
	if self.data.refresh ~= nil then
		local str = spliceIconStrById(self.data.cost_money);
		if self.data.shopType == Lua_ShopData.HERO_SHOP then
			if self.data.leftTimes > 0 and self.data.leftFreeTimes > 0 then
				self.refreshBtn:setLangValue(125026);
			else
				self.refreshBtn.label = LanUtil.formateStr(125017, str, numberTrans(self.data.cost));
			end
			self.remainTimeTxt.text = LanUtil.formateStr(125029, tostring(self.data.leftTimes), tostring(self.data.totalTimes));
		elseif self.data.shopType == Lua_ShopData.TALENT_SHOP then
			if self.data.leftTimes > 0 then 
				if self.data.leftFreeTimes > 0 then
					self.refreshBtn.label = LanUtil.formateStr(125028, tostring(self.data.leftFreeTimes), tostring(self.data.free_refresh));
				else
					self.refreshBtn.label = LanUtil.formateStr(125017, str, numberTrans(self.data.cost));
				end
			else
				self.refreshBtn:setLangValue(125041);
			end
			self.remainTimeTxt.text = LanUtil.formateStr(125029, tostring(self.data.leftTimes), tostring(self.data.totalTimes));

			self.showTimeStr = LanUtil.getValue(125027);
		elseif self.data.shopType == Lua_ShopData.TREASURE_SHOP then
			self.refreshBtn.label = LanUtil.formateStr(125030, str, numberTrans(self.data.cost));
			self.showTimeStr = LanUtil.getValue(125031);
		end

		self.refreshBtn:setGray(self.data.leftTimes <= 0);

		if self.data.nextTicks > 0 then
			self:startTimer();
		else
			self:updateTimer();
		end	
	end
end

function Lua_ShopPanel:startTimer()
	if not self.isTimer then
		self.isTimer = true;
		self:updateTimer();
		self:addTimer("updateTimer", 1, self, self.updateTimer);
	end
end

function Lua_ShopPanel:updateTimer()
	local time = self.data.nextTicks - os.time();
	if time <= 0 then
		time = 0;
		self:removeTimer(self, self.updateTimer);
		self.isTimer = false;	
	end
	self.refreshTimeTxt.text = LanUtil.formateStr(self.showTimeStr, " <color=#3BF25A>"..TimeTransform.getInstance():transSeconds6(time, true, true).."</color>");
end

function Lua_ShopPanel:onRefreshBtnClick(go)
	if self.data == nil then
		return;
	end
	self:superCall("onRefreshBtnClick", go);
	
	if self.data.leftFreeTimes > 0 then--免费刷新
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 0);
	elseif self.data.leftTimes > 0 then--自费刷新
		if DataCenter.moneyData:isMoney(self.data.cost_money) then
			if not DataCenter.moneyData:isMoneyEnough(self.data.cost_money, self.data.cost, true, true) then
				return;
			end
		else
			if DataCenter.packData:getItemCountById(self.data.cost_money) < self.data.cost then
				DataCenter.packUtil:openPathWindow(self.data.cost_money, false);
				return;
			end
		end
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 1);
	elseif self.data.leftBuyTimes > 0 then--购买刷新
		Lua_WindowUtil.openWin("Lua_BuyTimesWindow", Lua_WinParam.ACTION_OPEN, self.data);
	else
		OperateAlert.showLangValue(125054);
	end
end