--[[
	local param = {
		id = 000000, -- 购买道具id
		itemCount = 1, -- 购买一份商品所携带的数量
		
		showStyle = 1, -- 显示的类型 默认 1：限购， 单价；  2：已拥有， 限购
		limitCount = 1, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
		costId = 0000000, -- 消耗道具id
		costCount = 10, -- 消耗道具数量
		tipStr = "提示文本",
		isShowTipWindow = false, -- 点击购买按钮时，是否显示提示窗口
		isGray = false, -- 最小、最大、-、+按钮是否置灰
		isLimitBtn = false; -- 最小、最大、-、+按钮是否可点击
		isShowBackBtn = false, -- 是否显示返回按钮
		cancelBtnStr = "取消", -- 默认取消
		sureBtnStr = "确定", -- 默认确定
		owner = self, 
		callFunc = , -- 回调事件
		priceStyle =, -- 价格显示类型 ：默认 0--背包数量/本次购买消耗数量  1--只显示本次购买消耗数量
		font_size = 26 -- tipWindow文本字体大小, 默认27不填
		iconWidth 
		iconHeight
	}
--]]

Lua_ShoppingGoodsWindow = class("Lua_ShoppingGoodsWindow", Lua_Window);
function Lua_ShoppingGoodsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ShoppingGoodsWindow";
	self.skinName = "ShoppingGoodsWindow_skin";
	self.showBlackMask = true
	self.isClickClose = true;
end

function Lua_ShoppingGoodsWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setLocation(-105, 108, 0);
    self.itemIcon:setCanClick(false);

	self.numberInputItem = Lua_NumberInputItem.new(self.content);
	self.numberInputItem:setCallBack(self, self.updateCount);
	self.btnSure:addClickFuntion(self, self.onSureClick);
	self.btnCancel:addClickFuntion(self, self.hide);
	self.btnCancel:setEnable(false);
end

function Lua_ShoppingGoodsWindow:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.numberInputItem ~= nil then
		self.numberInputItem:dispose();
		self.numberInputItem = nil;
	end

	self:superCall("dispose");
end

function Lua_ShoppingGoodsWindow:showWin(param)
	self:superCall("showWin", param);

	local itemCount = param.itemCount or 1;
	local itemInfo = Lua_ToolVo.createToolVo(param.id, itemCount);
	self.itemNameTxt.text = itemInfo.name;
	self.itemIcon:setData(itemInfo);
	
	-- 限购数量
	local limitCount = param.limitCount;
	limitCount = limitCount or 1;
	if limitCount < 0 then
		self.limitTxt.text = nil;
	elseif limitCount == 0 then
		self.limitTxt:setLangValue(125046);
	else
		self.limitTxt.text = LanUtil.formateStr(125035, tostring(limitCount));
	end

	-- 消耗道具
	itemInfo = Lua_ToolVo.createToolVo(param.costId);
	self.costSp_1:setAltas(itemInfo.atlas, itemInfo.sprite);
	self.costSp_2:setAltas(itemInfo.atlas, itemInfo.sprite);

	self.singlePrice = param.costCount or 0;
	self.costCountTxt.text = self.singlePrice;

	-- 购买最大数量限制
	self.hasCount = DataCenter.packData:getItemCountById(param.costId);
	self.buyMaxNum = Mathf.Floor(self.hasCount / self.singlePrice);
	if limitCount > 0 and limitCount < self.buyMaxNum then
		self.buyMaxNum = limitCount;
	end
	if self.buyMaxNum <= 0 then
		self.selectNum = 0;
		self.buyMaxNum = 1;
	else
		self.selectNum = 1;
	end
	self.numberInputItem:setValue(1, 1, self.buyMaxNum);

	self.totalPrice = self.selectNum * self.singlePrice;
	self:showTotalPriceTxt();

	self.tipTxt.text = param.tipStr;

	self:setInputState();
	self:showButton();



	-- 显示类型(显示限购，单价； 还是显示已拥有，限购)
	local showStyle = param.showStyle == nil and 1 or param.showStyle;
	self.singlePriceObj:SetActive(showStyle == 1);
	if showStyle == 1 then
		self.hasNumTxt.text = nil;
		self.limitTxt:setLocation(50, 109);
	elseif showStyle == 2 then
		self.hasNumTxt.text = LanUtil.formateStr(125053, numberTrans(DataCenter.packData:getItemCountById(param.id)));
		self.hasNumTxt:setLocation(50, 109);
		self.limitTxt:setLocation(50, 74);
	end
end

function Lua_ShoppingGoodsWindow:showTotalPriceTxt()
	local totalPriceStyle = self.showData.priceStyle and tonumber(self.showData.priceStyle) or 0;
	local str;

	local color = "fefefe";
	if self.hasCount < self.totalPrice then
		color = "ee2c24";
	end
	if totalPriceStyle == 0 then
		str = Lua_ColorDefine.getColorStr(color, numberTrans(self.hasCount).."/"..self.totalPrice);
	elseif totalPriceStyle == 1 then
		str = self.totalPrice;
	end

	self.totalPriceTxt.text = str;
end

function Lua_ShoppingGoodsWindow:showButton()
	if self.showData.isShowBackBtn ~= true then
		self.btnSure:setLocation(0, -192);
		self.btnCancel:setEnable(false);
	else
		self.btnSure:setLocation(186, -192);
		self.btnCancel:setEnable(true);
		self.btnCancel.label = self.showData.cancelBtnStr or LanUtil.getValue(125048);
	end

	self.btnSure.label = self.showData.sureBtnStr or LanUtil.getValue(125047);
end

function Lua_ShoppingGoodsWindow:setInputState()
	if self.showData.isGray then
		self.numberInputItem:setBtnGray(true);
	end

	if self.showData.isLimitBtn then -- 最小、最大、-、+按钮是否可点击
		self.numberInputItem:removeClickFun();
	end
end

function Lua_ShoppingGoodsWindow:updateCount(val)
	if self.showData == nil then
		return;
	end

	if val > self.buyMaxNum then
		val = self.buyMaxNum;
	elseif val < 1 then
		val = 1;
	end

	self.selectNum = val;
	self.totalPrice = self.selectNum * self.singlePrice;
	self:showTotalPriceTxt();
end

function Lua_ShoppingGoodsWindow:onSureClick(go)
	if self.showData.isShowTipWindow then
		-- 消耗道具
		local costId = self.showData.costId;
		local costVo = Lua_ToolVo.createToolVo(costId);
		local iconWidth, iconHeight = 120, 120;
		if self.showData.iconWidth ~= nil and self.showData.iconWidth > 0 then 
			iconWidth = self.showData.iconWidth;
		elseif costVo.iconWidth ~= nil and costVo.iconWidth > 0 then
			iconWidth = costVo.iconWidth;
		end

		if self.showData.iconHeight ~= nil and self.showData.iconHeight > 0 then 
			iconHeight = self.showData.iconHeight;
		elseif costVo.iconHeight ~= nil and costVo.iconHeight > 0 then
			iconHeight = costVo.iconHeight;
		end

		local str = spliceIconStr(costVo.iconAtlas, costVo.iconSprite, iconWidth, iconHeight);
		local costName = costVo.name;

		costVo = Lua_ToolVo.createToolVo(self.showData.id);
		local haveCount = DataCenter.packData:getItemCountById(self.showData.id);
		local des = LanUtil.formateStr(125010, str, tostring(self.totalPrice), costName, costVo.colorName, numberTrans(haveCount));
		local tipsData = { 
			titleAtlas = "shop_atlas_1", 
			titleSprite = "ui_gmqr_title_02", 	
			font_size = self.showData.font_size;
			des = des, 
			btnType = 1, 
			owner = self, 
			sureFun = self.onSureBuy };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_AUTO, tipsData);
	else
		if self.hasCount < self.totalPrice then--材料不够
			DataCenter.packUtil:openPathWindow(self.showData.costId, false);
			self:hide();
			return
		end
		self:onSureBuy();
	end
end

function Lua_ShoppingGoodsWindow:onSureBuy()
	if self.showData.owner ~= nil and self.showData.callFunc ~= nil then
		self.showData.callFunc(self.showData.owner, self.showData.id, self.selectNum); --self.showData.id：购买道具id， self.selectNum：购买数量
		self:hide();
	end
end