checkRequire("Lua_DialogueBubbleItem");
checkRequire("Lua_SpiritShopItem");
Lua_SpiritShopWindow = class("Lua_SpiritShopWindow", Lua_Window);
function Lua_SpiritShopWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_SpiritShopWindow";
	self.skinName = "SpiritShopWindow_skin";
	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.isFullSizeWin = true;
	self.isFullPaving = true;
	self.showWinBg = true;
	self.showBackBtn = true;
	self.winBgPath = "/images/shop/ui_tmd_bj_001.jpg";

	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/shop/ui_tmd_widget_001.png", Lua_LoadFileType.IMG);
end

function Lua_SpiritShopWindow:buildShowItem()
	self:superCall("buildShowItem");

	local bubbleId, type = DataCenter.shopUtil:getBubbleIdAndType(self.classname);
	self.dialogueBubbleItem = Lua_DialogueBubbleItem.new(self.content, type);
	self.dialogueBubbleItem:setData(bubbleId);

	self.winBg.anchorValue = 7;
	self.winBg.pivotValue = 7;
	self.moneyItemArr = Array();
	self.itemArr = Array();

	self.isFirstIn = true;

	self.personEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/temaidian", "temaidian", -145, -290);
	-- self.personEff.anchorValue = 1;
	self.personEff.siblingIndex = 1;

	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);
	self.introduceSp:addClickFuntion(self, self.onIntroduceSpClick);

	self:initMoneyInfo();

	self:addLuaEvent("UPDATE_SHOP_INFO", self, self.updateShowInfo);
	self:addLuaEvent("REFRESH_SHOP_INFO", self, self.updateShopTypePanel); -- 到达商店刷新时间
end

function Lua_SpiritShopWindow:showWin(param)
	self:superCall("showWin", param);

	if type(param) == "table" then
		DataCenter.shopData.shopType = param.secondIdx;
	else
		DataCenter.shopData.shopType = Lua_ShopData.SPIRIT_SHOP;
	end
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sShopInfo(Lua_ShopData.SPIRIT_SHOP);
end

function Lua_SpiritShopWindow:initMoneyInfo()
	self.data = DataCenter.shopUtil:getShopTypeVo(Lua_ShopData.SPIRIT_SHOP);
	self.data.bOpenSpritShop = true;
	if self.data.moneyType ~= nil then
		local item;
		for i = 1, #self.data.moneyType do
			item = Lua_MoneyItem.new(self.content);
			item:setMoneyType(self.data.moneyType[i]);
			item:setRectAnchor(1);
			item:setCanClick(true);
			item:setLocation(439 - i * 190, -26, 0);
			-- item:setSiblingIndex(i);
			self.moneyItemArr:add(item);
		end
	end
end

function Lua_SpiritShopWindow:updateShowInfo()
	local item;
	local posX;
	local posY;
	local showList = DataCenter.shopData:getCurShopItemList(Lua_ShopData.SPIRIT_SHOP);
	for i = 1, #showList do
		posX = -206 + 205 * ((i - 1) % 3);
		posY = 1035 - 300 * math.ceil(i / 3);
		item = self.itemArr[i];
		if item == nil then
			item = Lua_SpiritShopItem.new(self.content);
			self.itemArr:add(item);
		end
		item.contentName = "Lua_SpiritShopItem_" .. i;
		showList[i].highlightEff = "ui_tmd_shuaxin";
		item:setData(showList[i]);
		item:setRectAnchor(7);
		item:setLocation(posX, posY, 0);
		if self.isFirstIn then 
			item:setEnable(false);
		end
	end

	if self.isFirstIn then
		self.isFirstIn = false;
		self.tweenIdx = 0;
		self:onPlayTween();
		self:addTimer("onPlayTween", 0.04, self, self.onPlayTween);
	end

	if self.data.leftFreeTimes > 0 then
		self.refreshBtn.label = LanUtil.formateStr(125036, tostring(self.data.leftFreeTimes), tostring(self.data.free_refresh));
		self.refreshBtn:setStyle(5);
	else
		if self.data.leftTimes > 0 then
			self.refreshBtn.label = LanUtil.formateStr(125017, spliceIconStrById(self.data.cost_money), numberTrans(self.data.cost));
			self.refreshBtn:setStyle(5);
		else
			self.refreshBtn:setLangValue(125041);
			self.refreshBtn:setStyle(7);
		end
	end
    
    local str;
    if tonumber(self.data.leftTimes) > 0 then
		str = Lua_ColorDefine.getColorStr("3bf25a", tostring(self.data.leftTimes));
	else
		str = Lua_ColorDefine.getColorStr("FF4B4C", tostring(self.data.leftTimes));
	end
	self.remainTimeTxt.text = LanUtil.formateStr(125037, str, tostring(self.data.totalTimes));
    
	

	if self.data.nextTicks > 0 then
		self:startTimer();
		self:updateTimer();
	else
		self:updateTimer();
	end

	-- 检测引导
	self:checkWinGuide();
end

function Lua_SpiritShopWindow:startTimer()
	if not self.isTimer then
		self.isTimer = true;
		self:addTimer("updateTimer", 1, self, self.updateTimer);
	end
end

function Lua_SpiritShopWindow:updateTimer()
	local time = self.data.nextTicks - os.time();
	if time <= 0 then
		time = 0;
		self.isTimer = false;
		self:removeTimer(self, self.updateTimer);
	end
	local str = TimeTransform.getInstance():transSeconds6(time, true, true);
	self.refreshTimeTxt.text = Lua_ColorDefine.getColorStr("3bf25a", str);
end

function Lua_SpiritShopWindow:onRefreshBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();
	
	if self.data.leftFreeTimes > 0 then -- 免费刷新
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 0);
		self:showItemEffect();
	elseif self.data.leftTimes > 0 then -- 自费刷新
		if DataCenter.moneyData:isMoney(self.data.cost_money) then
			if not DataCenter.moneyData:isMoneyEnough(self.data.cost_money, self.data.cost, true, true) then
				return;
			end
		else
			if DataCenter.packData:getItemCountById(self.data.cost_money) < self.data.cost then
				DataCenter.packUtil:openPathWindow(self.data.cost_money, false);
				return;
			end
		end
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 1);
		self:showItemEffect();
	elseif self.data.leftBuyTimes > 0 then -- 购买刷新
		Lua_WindowUtil.openWin("Lua_BuyTimesWindow", Lua_WinParam.ACTION_OPEN, self.data);
	else
		OperateAlert.showLangValue(125020);
	end
end

function Lua_SpiritShopWindow:showItemEffect()
	for i = 1, self.itemArr:getSize() do
		self.itemArr[i]:showHighlightEff();
	end
end

function Lua_SpiritShopWindow:onIntroduceSpClick()
	local tipsData = { des = LanUtil.getValue(125043), posX = 180, posY = -303 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_SpiritShopWindow:updateShopTypePanel()
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sShopInfo(Lua_ShopData.SPIRIT_SHOP);
end

function Lua_SpiritShopWindow:dispose()
	self:removeTimer(self, self.onPlayTween);
	
	if self.dialogueBubbleItem ~= nil then
		self.dialogueBubbleItem:dispose();
		self.dialogueBubbleItem = nil;
	end
	if self.moneyItemArr ~= nil then
		self.moneyItemArr:dispose();
		self.moneyItemArr:clear();
		self.moneyItemArr = nil;
	end
	if self.itemArr ~= nil then
		self.itemArr:dispose();
		self.itemArr:clear();
		self.itemArr = nil;
	end
	if self.personEff ~= nil then
		self.personEff:dispose();
		self.personEff = nil;
	end
	DataCenter.shopData:dispose();

	self:superCall("dispose");
end

-- 引导同步
function Lua_SpiritShopWindow:updateGuide(guide, info)
	if info == nil then
		return;
	end

	-- 检测目标位置，返回path
	local itemId = info.itemId;
	if itemId ~= nil and self.itemArr ~= nil then
		local num = info.count ~= nil and info.count or 0;
		local len = self.itemArr:getSize();
		for i = 1, len do
			local item = self.itemArr[i];
			local vo = item.showData;
			if vo ~= nil and vo.itemId == itemId then
				DataCenter.guideCommonData.guideClickObjTarget = item.content;
				Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guide);
				return;	
			end
		end
	end
end

function Lua_SpiritShopWindow:onPlayTween()
	self.tweenIdx = self.tweenIdx + 1;
	if self.tweenIdx > self.itemArr:getSize() then
		self:removeTimer(self, self.onPlayTween);
		return;
	end
	local item = self.itemArr[self.tweenIdx];
	item:setEnable(true);
	TweenUtil.getInstance():addTweenTargetAlpha(item.content, 0.2, 0, -1, true);
end