Lua_ShopItem = class("Lua_ShopItem", Lua_ListCell);
function Lua_ShopItem:ctor(p)
	self:superCall("ctor", p, "ShopItem_skin");
end

function Lua_ShopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.item = Lua_ItemIcon.new(self.content);
	self.item:setLocation(0, 33, 0);
	self.item:setScale(0.9, 0.9);
	self.item:setCanClick(false);
	self.item:setSiblingIndex(2);
end

function Lua_ShopItem:dispose()
	if self.item ~= nil then
		self.item:dispose();
		self.item = nil;
	end
	if self.data ~= nil then
		self.data.highlightEff = nil;
		self.data = nil;
	end
	if self.highlightEff ~= nil then
		self.highlightEff:dispose();
		self.highlightEff = nil;
	end
	self:superCall("dispose");
end

function Lua_ShopItem:setData(data)
	if data == nil then
		return;
	end

	self.data = data;
	self.itemId = data.itemVo.id;
	self.item:setData(data.itemVo);
	self.item:setGray(false);

	-- self.itemNameTxt.text = data.itemVo.name;

	if data.recommend > 0 then
		-- self.leftTop:SetActive(true);
		-- self.leftBg:setAltas("shop_atlas_1", "ui_sd_label_01");
		-- self.leftTopLabel.effectColorStr = Lua_ColorDefine.transColor("127E00");
		-- self.leftTopLabel:setLangValue(125012);
	elseif data.discount > 0 then
		self.leftTop:SetActive(true);
		self.leftBg:setAltas("shop_atlas_1", "xui_sd_label_" .. data.discount);
		-- self.leftTopLabel.effectColorStr = Lua_ColorDefine.transColor("AE342C");
		-- self.leftTopLabel.text = LanUtil.formateStr(125013, tostring(data.discount));
	else
		self.leftTop:SetActive(false);
	end

	--社区（联盟）等级不符合该商品的解锁条件
	self.isLeagueNotOpen = data.shopType == 5 and not data.isLeagueOpen; -- 5为社区（联盟) isLeagueOpen:该商品是否符合开启条件
	if self.data.isSoldOut then
		if self.isLeagueNotOpen then --社区（联盟）
			self.soldOut:SetActive(false);
		else
			self.soldOut:SetActive(true);
		end
	else
		self.soldOut:SetActive(false);
	end


	if data.vip_level > DataCenter.roleData.vip then
		self.conditionTxt.text = LanUtil.formateStr(125003, tostring(data.vip_level));
		self.costObj:SetActive(false);
	else
		self.conditionTxt.text = "";
		self.costObj:SetActive(true);

		if data.moneyCount ~= 0 then
			local toolVo = Lua_ToolVo.createToolVo(data.moneyType);
			if toolVo ~= nil then
				self.costIcon:setAltas(toolVo.iconAtlas, toolVo.iconSprite);
				self.costIcon:SetDimensions(toolVo.iconWidth, toolVo.iconHeight);
			end

			if DataCenter.packData:getItemCountById(data.moneyType) < data.moneyCount then
				self.costCount.text = LanUtil.formateStr(125044, numberTrans(data.moneyCount));
			else
				self.costCount.text = numberTrans(data.moneyCount);
			end
		else
			self.costCount:setLangValue(125011);
		end
	end
	
	if self.isLeagueNotOpen then --社区（联盟）
		self.item:setGray(true);
		self.timesTxt.text = LanUtil.formateStr(125042, tostring(data.communityLevel));
	elseif data.shopType == Lua_ShopData.HERO_SHOP then
		local num = numberTrans(DataCenter.packData:getItemCountById(data.itemVo.id)); 
		self.timesTxt.text = LanUtil.formateStr(125032, tostring(num));
	elseif data.shopType == Lua_ShopData.TALENT_SHOP then
		local str = data.leftTimes.."/"..data.limitTimes;
		self.timesTxt.text = LanUtil.formateStr(125033, str);
	elseif data.shopType == Lua_ShopData.PEAK_SHOP and DataCenter.shopData.segmentLv < data.peak_duel_lvl_id then
		local segmentInfo = DataCenter.peakDuelUtil:getSegmentInfoByid(data.peak_duel_lvl_id);
		self.timesTxt.text = LanUtil.formateStr(125038, segmentInfo.name);
		self.item:setGray(true);
	elseif data.shopType == Lua_ShopData.EQUIP_SHOP and data.limit_grade > DataCenter.equipCopyData.max_difficulty then --魔灵商店
		self.item:setGray(true);
		self.timesTxt.text = LanUtil.formateStr(125050, data.limit_grade);
	else
		local str = data.leftTimes.."/"..data.limitTimes;
		if data.limit_type == 1 then
			self.timesTxt.text = LanUtil.formateStr(125000, str);
		elseif data.limit_type == 2 then
			self.timesTxt.text = LanUtil.formateStr(125001, str);
		elseif data.limit_type == 3 then
			self.timesTxt.text = LanUtil.formateStr(125002, str);
		elseif data.limit_type == 4 then
			self.timesTxt.text = LanUtil.formateStr(125040, str);
		else
			self.timesTxt.text = "";
		end
	end

	self:showHighlightEff(data.highlightEff);
end

function Lua_ShopItem:showHighlightEff(effectName)
	if effectName ~= nil then
		if self.highlightEff == nil then
			self.highlightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/"..effectName, effectName, 0, -2);
			self.highlightEff:SetRenderQueue(5, 1, UIEffect.NormalSort);
		end
		self.highlightEff:setEnable(true);
	else
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_ShopItem:checkOutBound(showRect)
	local rect = Lua_Rectangle.new(self.itemX - 50, self.itemY - 50, 100, 100);
	if showRect:containeRect(rect) == true then
		self.item:showEffect(true);
		if self.data.highlightEff ~= nil and self.highlightEff ~= nil then
			self.highlightEff:setEnable(true);
		end
	else
		self.item:showEffect(false);
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_ShopItem:onPressClick()
	-- 是否点击商品道具
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	if self.item:checkInBound(winPos.x, winPos.y) then
		local tvo = Lua_ToolVo.createToolVo(self.itemId);
		DataCenter.packUtil:showItemInfo(tvo);
		return;
	end

	--社区（联盟）
	if self.isLeagueNotOpen then
		OperateAlert.show(LanUtil.formateStr(125042, tostring(self.data.communityLevel)));
		return;
	end

	-- 购买
	if self.data ~= nil then
		if self.data.shopType == Lua_ShopData.PEAK_SHOP and DataCenter.shopData.segmentLv < self.data.peak_duel_lvl_id then
			local segmentInfo = DataCenter.peakDuelUtil:getSegmentInfoByid(self.data.peak_duel_lvl_id);
			OperateAlert.show(LanUtil.formateStr(125039, segmentInfo.name));
			return;
		elseif self.data.shopType == Lua_ShopData.EQUIP_SHOP and self.data.limit_grade > DataCenter.equipCopyData.max_difficulty then --魔灵商店
			OperateAlert.show(LanUtil.formateStr(125049, tostring(self.data.limit_grade)));
			return;
		end

		if self.data.isSoldOut then
			OperateAlert.showLangValue(125014);
		elseif self.data.vip_level > DataCenter.roleData.vip then
			OperateAlert.showLangValue(125021);
		else
			if DataCenter.moneyData:isMoneyEnough(self.data.moneyType, self.data.moneyCount, true, true) then
				local param = {
					id = self.data.itemVo.id, -- 购买道具id
					itemCount = self.data.itemVo.count, -- 购买一份商品所携带的数量

					limitCount = self.data.leftTimes, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
					costId = self.data.moneyType, -- 消耗道具id
					costCount = self.data.moneyCount, -- 消耗道具数量
					tipStr = "",
					isShowTipWindow = true, -- 点击购买按钮时，是否显示提示窗口
					isShowBackBtn = false, -- 是否显示返回按钮
					cancelBtnStr = LanUtil.getValue(125051), -- 默认取消
					sureBtnStr = LanUtil.getValue(125052), -- 默认确定
					owner = self, 
					callFunc = self.onSureBuy, -- 回调事件
					priceStyle = 1, -- 价格显示类型
					font_size = 26 -- tipWindow文本字体大小
				};
				Lua_WindowUtil.openWin("Lua_ShoppingGoodsWindow", Lua_WinParam.ACTION_OPEN, param);
			end
		end
	end
end

function Lua_ShopItem:onSureBuy(itemId, selectNum)
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sBuyShopItem(self.data.id, self.data.shopType, selectNum, self.data.index);
end

-- 判断是否范围内
function Lua_ShopItem:checkInBound(posX, posY)
	local half_w = self.bg.width / 2;
	local half_h = self.bg.height / 2;
	self.minX = self.posX - half_w;
	self.maxX = self.posX + half_w;
	self.minY = self.posY - half_h;
	self.maxY = self.posY + half_h;

	if posX >= self.minX and posX <= self.maxX and posY >= self.minY and posY <= self.maxY then
		return true;
	end
	return false;
end