Lua_SpiritShopItem = class("Lua_SpiritShopItem", Lua_ListCell);
function Lua_SpiritShopItem:ctor(p)
	self:superCall("ctor", p, "SpiritShopItem_skin");
end

function Lua_SpiritShopItem:buildShowItem()
	self:superCall("buildShowItem");

	self.item = Lua_ItemIcon.new(self.content);
	self.item:setCanClick(true);
	self.item:setSiblingIndex(1);
	self.item:setScale(0.9, 0.9);
	self.item:setLocation(0, 16);

	self.bg.clickScale = false;
	self.bg:addClickFuntion(self, self.onPressClick);
end

function Lua_SpiritShopItem.Get:showData()
	return self._data;
end

function Lua_SpiritShopItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end
	self.item:setData(data.itemVo);
	--self.itemName.text = data.itemVo.name;

	if data.recommend > 0 then
		self.discountIcon:setEnable(true);
		-- self.discountIcon:setAltas("shop_atlas_1", "推荐图片");
	elseif data.discount > 0 then
		self.discountIcon:setEnable(true);
		self.discountIcon:setAltas("shop_atlas_1", "xui_sd_label_"..data.discount);
	else
		self.discountIcon:setEnable(false);
	end
    
	if data.moneyCount ~= 0 then
		local toolVo = Lua_ToolVo.createToolVo(data.moneyType);
		if toolVo ~= nil then
			self.costIcon:setAltas(toolVo.iconAtlas, toolVo.iconSprite);
		end

		if DataCenter.packData:getItemCountById(data.moneyType) < data.moneyCount then
			self.costCount.text = LanUtil.formateStr(125045, numberTrans(data.moneyCount));
		else
			self.costCount.text = numberTrans(data.moneyCount);
		end
	else
		self.costCount:setLangValue(125011);
	end
	self.costCount:resetSize();
	self.costIcon:setLocation(-14 - (self.costCount.width - 18) / 2, -70);
	self.sellOutObj:SetActive(data.isSoldOut);
end

function Lua_SpiritShopItem:showHighlightEff()
	local effectName = self._data.highlightEff;
	if effectName ~= nil then
		if self.highlightEff == nil then
			self.highlightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/"..effectName, effectName, 0, 13);
		end
		self.highlightEff:setEnable(false);
		self.highlightEff:setEnable(true);
	else
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_SpiritShopItem:checkOutBound(showRect)
	local rect = Lua_Rectangle.new(self.itemX - 50, self.itemY - 50, 100, 100);
	if showRect:containeRect(rect) == true then
		self.item:showEffect(true);
		if self._data.highlightEff ~= nil and self.highlightEff ~= nil then
			self.highlightEff:setEnable(true);
		end
	else
		self.item:showEffect(false);
		if self.highlightEff ~= nil then
			self.highlightEff:setEnable(false);
		end
	end
end

function Lua_SpiritShopItem:onPressClick()
	if self._data ~= nil then
		if self._data.isSoldOut then
			OperateAlert.showLangValue(125014);
		elseif self._data.vip_level > DataCenter.roleData.vip then
			OperateAlert.showLangValue(125021);
		else
			if DataCenter.moneyData:isMoneyEnough(self._data.moneyType, self._data.moneyCount, true, true) then
				local param = {
					id = self._data.itemId, -- 购买道具id
					itemCount = self._data.itemAmount, -- 购买一份商品所携带的数量

					limitCount = self._data.leftTimes, -- 限购数量，小于0不显示， = 0显示不限购， 默认为1,
					costId = self._data.moneyType, -- 消耗道具id
					costCount = self._data.moneyCount, -- 消耗道具数量
					tipStr = "",
					isShowTipWindow = false, -- 点击购买按钮时，是否显示提示窗口
					isLimitBtn = true, -- 最小、最大、-、+按钮是否可点击
					isShowBackBtn = false, -- 是否显示返回按钮
					cancelBtnStr = LanUtil.getValue(125051), -- 默认取消
					sureBtnStr = LanUtil.getValue(125052), -- 默认确定
					owner = self, 
					callFunc = self.onSureBuy, -- 回调事件
					priceStyle = 1 -- 价格显示类型
				};
				Lua_WindowUtil.openWin("Lua_ShoppingGoodsWindow", Lua_WinParam.ACTION_OPEN, param);
			end
		end
	end
end

function Lua_SpiritShopItem:onSureBuy(itemId, selectNum)
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sBuyShopItem(self._data.id, self._data.shopType, selectNum, self._data.index);
end

function Lua_SpiritShopItem:dispose()
	TweenUtil.getInstance():stop(self.content);
	if self.item ~= nil then
		self.item:dispose();
		self.item = nil;
	end
	if self.highlightEff ~= nil then
		self.highlightEff:dispose();
		self.highlightEff = nil;
	end
	self._data = nil;
	
	self:superCall("dispose");
end